@@ -189,7 +189,7 @@ if [ ${#COMMAND_LINE_ARGS[@]} -eq 0 ]; then
     exit $ERR_BAD_COMMAND_LINE
 fi
 
-set_exit_trap
+core_init 'plowdel'
 
 DCOOKIE=$(create_tempfile) || exit
 
