@@ -268,7 +268,7 @@ if [ ${#COMMAND_LINE_ARGS[@]} -eq 0 ]; then
     exit $ERR_BAD_COMMAND_LINE
 fi
 
-set_exit_trap
+core_init 'plowlist'
 
 for URL in "${COMMAND_LINE_ARGS[@]}"; do
     LRETVAL=0
